==> aegis-4.19.tar.gz: aegis-4.19/fmtgen/type/enumeration.h <==
//
//	aegis - project change supervisor
//	Copyright (C) 1994 Peter Miller.
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for fmtgen/type/enumeration.c
//

#ifndef FMTGEN_TYPE_ENUMERATION_H
#define FMTGEN_TYPE_ENUMERATION_H

#pragma interface "type_enumeration_ty"

#include <type.h>
#include <nstring_list.h>

/**
  * The type_enumeration_ty class is used to represent the type of a
  * field with an enumerated value.
  */
class type_enumeration_ty:
    public type_ty
{
public:
    /**
      * The destructor.
      */
    virtual ~type_enumeration_ty();

    /**
      * The constructor.
      */
    type_enumeration_ty(const nstring &name);

    // See base class for documentation.
    void gen_include() const;

    // See base class for documentation.
    void gen_include_declarator(const nstring &variable_name, bool is_a_list)
	const;

    // See base class for documentation.
    void gen_code() const;

    // See base class for documentation.
    void gen_code_declarator(const nstring &variable_name, bool is_a_list,
	int attributes) const;

    // See base class for documentation.
    void gen_code_call_xml(const nstring &form_name, const nstring &member_name,
	int attributes) const;

    // See base class for documentation.
    void gen_free_declarator(const nstring &variable_name, bool is_a_list)
	const;

    // See base class for documentation.
    void member_add(const nstring &member_name, type_ty *member_type,
	int attributes);

    // See base class for documentation.
    nstring c_name_inner() const;

    // See base class for documentation.
    bool has_a_mask() const;

private:
    nstring_list elements;

    /**
      * The default constructor.   Do not use.
      */
    type_enumeration_ty();

    /**
      * The copy constructor.   Do not use.
      */
    type_enumeration_ty(const type_enumeration_ty &);

    /**
      * The assignment operator.   Do not use.
      */
    type_enumeration_ty &operator=(const type_enumeration_ty &);
};

#endif // FMTGEN_TYPE_ENUMERATION_H

==> aegis-4.21.tar.gz: aegis-4.21/fmtgen/type/enumeration.h <==
//
//	aegis - project change supervisor
//	Copyright (C) 1994 Peter Miller.
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for fmtgen/type/enumeration.c
//

#ifndef FMTGEN_TYPE_ENUMERATION_H
#define FMTGEN_TYPE_ENUMERATION_H

#pragma interface "type_enumeration_ty"

#include <type.h>
#include <nstring/list.h>

/**
  * The type_enumeration_ty class is used to represent the type of a
  * field with an enumerated value.
  */
class type_enumeration_ty:
    public type_ty
{
public:
    /**
      * The destructor.
      */
    virtual ~type_enumeration_ty();

    /**
      * The constructor.
      */
    type_enumeration_ty(const nstring &name);

    // See base class for documentation.
    void gen_include() const;

    // See base class for documentation.
    void gen_include_declarator(const nstring &variable_name, bool is_a_list)
	const;

    // See base class for documentation.
    void gen_code() const;

    // See base class for documentation.
    void gen_code_declarator(const nstring &variable_name, bool is_a_list,
	int attributes) const;

    // See base class for documentation.
    void gen_code_call_xml(const nstring &form_name, const nstring &member_name,
	int attributes) const;

    // See base class for documentation.
    void gen_code_copy(const nstring &member_name) const;

    // See base class for documentation.
    void gen_code_trace(const nstring &name, const nstring &value) const;

    // See base class for documentation.
    void gen_free_declarator(const nstring &variable_name, bool is_a_list)
	const;

    // See base class for documentation.
    void member_add(const nstring &member_name, type_ty *member_type,
	int attributes);

    // See base class for documentation.
    nstring c_name_inner() const;

    // See base class for documentation.
    bool has_a_mask() const;

private:
    nstring_list elements;

    /**
      * The default constructor.   Do not use.
      */
    type_enumeration_ty();

    /**
      * The copy constructor.   Do not use.
      */
    type_enumeration_ty(const type_enumeration_ty &);

    /**
      * The assignment operator.   Do not use.
      */
    type_enumeration_ty &operator=(const type_enumeration_ty &);
};

#endif // FMTGEN_TYPE_ENUMERATION_H
